# History

## 0.1.0 (2026-01-14)

- First release on PyPI.

## 1.0.0 (2026-03-17)

- Added `to_mzpaf()` function to convert `peptacular` Fragment objects to `PafAnnotation`
- `peptacular` is now a required dependency (previously optional)
- Added Zenodo DOI for citation
- Improved mass calculation for immonium ions with modifications
- Added caching for serialization and parsing results
